@@ -473,17 +473,18 @@ class Owner(models.Model):
                 # compile pocos into structures list
                 for poco in pocos:
                     office_id = poco["office_id"]
-                    if office_id in names:
+                    planet_name = names.get(office_id, "")
+                    if planet_name:
                         try:
-                            eve_planet = EvePlanet.objects.get(name=names[office_id])
+                            eve_planet = EvePlanet.objects.get(name=planet_name)
+                        except EvePlanet.DoesNotExist:
+                            name = ""
+                            planet_id = None
+                        else:
                             planet_id = eve_planet.id
                             name = eve_planet.eve_type.name_localized_for_language(
                                 STRUCTURES_DEFAULT_LANGUAGE
                             )
-
-                        except EvePlanet.DoesNotExist:
-                            name = names[office_id]
-                            planet_id = None
                     else:
                         name = None
                         planet_id = None
@@ -568,13 +569,13 @@ class Owner(models.Model):
 
     @staticmethod
     def _extract_planet_name(text: str) -> str:
-        """extract name of planet from assert name for a customs office"""
+        """Extract name of planet from assert name for a customs office."""
         reg_ex = re.compile(r"Customs Office \((.+)\)")
         matches = reg_ex.match(text)
-        return matches.group(1) if matches else text
+        return matches.group(1) if matches else ""
 
     def _fetch_starbases(self, token: Token) -> list:
-        """fetch starbases from ESI for self"""
+        """Fetch starbases from ESI for self."""
 
         add_prefix = self._logger_prefix()
         structures = list()
@@ -717,6 +718,7 @@ class Owner(models.Model):
             try:
                 notifications = self._fetch_notifications_from_esi(token)
                 notifications_count_new = self._store_notifications(notifications)
+                self._process_moon_notifications()
                 if notifications_count_new > 0:
                     logger.info(
                         "%s: Received %d new notifications from ESI",
@@ -724,7 +726,6 @@ class Owner(models.Model):
                         notifications_count_new,
                     )
                     self._process_timers_for_notifications(token)
-                    self._process_moon_notifications()
                     notifications_count_all += notifications_count_new
 
                 else:
@@ -872,32 +873,38 @@ class Owner(models.Model):
 
     def _process_moon_notifications(self):
         """processes notifications for timers if any"""
-        notifications = (
-            Notification.objects.filter(owner=self)
-            .filter(notif_type__in=NotificationType.relevant_for_moonmining)
-            .select_related("owner", "sender")
-            .order_by("timestamp")
-        )
-        structure_id_2_moon_id = dict()
-        for notification in notifications:
-            parsed_text = notification.get_parsed_text()
-            moon_id = parsed_text["moonID"]
-            structure_id = parsed_text["structureID"]
-            structure_id_2_moon_id[structure_id] = moon_id
-
         empty_refineries = Structure.objects.filter(
             owner=self,
             eve_type__eve_group_id=EveGroup.EVE_GROUP_ID_REFINERY,
             eve_moon__isnull=True,
         )
-        for refinery in empty_refineries:
-            if refinery.id in structure_id_2_moon_id:
-                logger.info("%s: Updating moon for structure %s", self, refinery)
-                eve_moon, _ = EveMoon.objects.get_or_create_esi(
-                    eve_id=structure_id_2_moon_id[refinery.id]
-                )
-                refinery.eve_moon = eve_moon
-                refinery.save()
+        if empty_refineries:
+            logger.info(
+                "%s: Trying to find moons for up to %d refineries which have no moon.",
+                self,
+                empty_refineries.count(),
+            )
+            notifications = (
+                Notification.objects.filter(owner=self)
+                .filter(notif_type__in=NotificationType.relevant_for_moonmining)
+                .select_related("owner", "sender")
+                .order_by("timestamp")
+            )
+            structure_id_2_moon_id = dict()
+            for notification in notifications:
+                parsed_text = notification.get_parsed_text()
+                moon_id = parsed_text["moonID"]
+                structure_id = parsed_text["structureID"]
+                structure_id_2_moon_id[structure_id] = moon_id
+
+            for refinery in empty_refineries:
+                if refinery.id in structure_id_2_moon_id:
+                    logger.info("%s: Updating moon for structure %s", self, refinery)
+                    eve_moon, _ = EveMoon.objects.get_or_create_esi(
+                        eve_id=structure_id_2_moon_id[refinery.id]
+                    )
+                    refinery.eve_moon = eve_moon
+                    refinery.save()
 
     def send_new_notifications(self, user: User = None) -> bool:
         """forwards all new notification for this owner to Discord"""
